( cd usr/share/doc/HTML/ru/konversation ; rm -rf common )
( cd usr/share/doc/HTML/ru/konversation ; ln -sf /usr/share/doc/HTML/ru/common common )
( cd usr/share/doc/HTML/et/konversation ; rm -rf common )
( cd usr/share/doc/HTML/et/konversation ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/da/konversation ; rm -rf common )
( cd usr/share/doc/HTML/da/konversation ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/sv/konversation ; rm -rf common )
( cd usr/share/doc/HTML/sv/konversation ; ln -sf /usr/share/doc/HTML/sv/common common )
( cd usr/share/doc/HTML/pt/konversation ; rm -rf common )
( cd usr/share/doc/HTML/pt/konversation ; ln -sf /usr/share/doc/HTML/pt/common common )
( cd usr/share/doc/HTML/en/konversation ; rm -rf common )
( cd usr/share/doc/HTML/en/konversation ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/it/konversation ; rm -rf common )
( cd usr/share/doc/HTML/it/konversation ; ln -sf /usr/share/doc/HTML/it/common common )
